@@ -405,7 +405,7 @@ static htp_status_t htp_tx_process_request_headers(htp_tx_t *tx) {
         //      (2.2.22 on Ubuntu 12.04 LTS) instead errors out with "Unknown Transfer-Encoding: identity".
         //      And it behaves strangely, too, sending a 501 and proceeding to process the request
         //      (e.g., PHP is run), but without the body. It then closes the connection.
-        if (bstr_cmp_c_nocase(te->value, "chunked") != 0) {
+        if (htp_header_has_token(bstr_ptr(te->value), bstr_len(te->value), (unsigned char*) "chunked") != HTP_OK) {
             // Invalid T-E header value.
             tx->request_transfer_coding = HTP_CODING_INVALID;
             tx->flags |= HTP_REQUEST_INVALID_T_E;
@@ -585,10 +585,7 @@ static htp_status_t htp_tx_process_request_headers(htp_tx_t *tx) {
     rc = htp_hook_run_all(tx->connp->cfg->hook_request_headers, tx);
     if (rc != HTP_OK) return rc;
 
-    // We cannot proceed if the request is invalid.
-    if (tx->flags & HTP_REQUEST_INVALID) {
-        return HTP_ERROR;
-    }
+    // We still proceed if the request is invalid.
 
     return HTP_OK;
 }
@@ -975,8 +972,13 @@ htp_status_t htp_tx_res_process_body_data_ex(htp_tx_t *tx, const void *data, siz
         case HTP_COMPRESSION_DEFLATE:
         case HTP_COMPRESSION_LZMA:
             // In severe memory stress these could be NULL
-            if (tx->connp->out_decompressor == NULL)
+            if (tx->connp->out_decompressor == NULL) {
+                if (data == NULL) {
+                    // we were already stopped on a gap finishing CL
+                    return HTP_OK;
+                }
                 return HTP_ERROR;
+            }
 
             struct timeval after;
             gettimeofday(&tx->connp->out_decompressor->time_before, NULL);
@@ -1345,7 +1347,8 @@ htp_status_t htp_tx_state_response_headers(htp_tx_t *tx) {
             tx->response_content_encoding = HTP_COMPRESSION_DEFLATE;
         } else if (bstr_cmp_c_nocasenorzero(ce->value, "lzma") == 0) {
             tx->response_content_encoding = HTP_COMPRESSION_LZMA;
-        } else if (bstr_cmp_c_nocasenorzero(ce->value, "inflate") == 0) {
+        } else if (bstr_cmp_c_nocasenorzero(ce->value, "inflate") == 0 ||
+                   bstr_cmp_c_nocasenorzero(ce->value, "identity") == 0) {
             // ignore
         } else {
             /* exceptional cases: enter slow path */
@@ -1453,7 +1456,7 @@ htp_status_t htp_tx_state_response_headers(htp_tx_t *tx) {
                                 "Compression bomb: multiple encoding with lzma");
                         break;
                     }
-                } else if (bstr_util_cmp_mem(tok, tok_len, "inflate", 7) == 0) {
+                } else if (bstr_util_cmp_mem(tok, tok_len, "inflate", 7) == 0 || bstr_util_cmp_mem(tok, tok_len, "none", 4) == 0) {
                     cetype = HTP_COMPRESSION_NONE;
                 } else {
                     // continue
